@@ -3,10 +3,10 @@
 import logging
 import shlex
 import subprocess
-from typing import Tuple
+from typing import List, Tuple, Union
 
 
-def run_command(cmd: str) -> Tuple[bool, str]:
+def run_command(cmd: Union[str, List[str]]) -> Tuple[bool, str]:
     """
     Run a command line (with no shell).
 
@@ -16,9 +16,21 @@ def run_command(cmd: str) -> Tuple[bool, str]:
 
     """
     logging.debug("Running command {!r}".format(cmd))
-    proc = subprocess.run(shlex.split(cmd), shell=False, check=False, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+    if isinstance(cmd, str):
+        cmd = shlex.split(cmd)
+    proc = subprocess.run(
+        cmd,
+        shell=False,
+        check=False,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+    )
     output = proc.stdout.decode("utf-8")
-    logging.debug("Command exited with {} status. Output: {!r}".format(proc.returncode, output))
+    logging.debug(
+        "Command exited with {} status. Output: {!r}".format(
+            proc.returncode, output
+        )
+    )
 
     return proc.returncode == 0, output
 
